@@ -20,6 +20,13 @@ This CDK library is a WIP and not ready for production use.
 ```
 LAMBDA_FUNCTION_NAME='<name you noted earlier>' pytest ./handler_tests/<handler>/test.py -rA --capture=sys
 ```
+
+* The `test.py` also looks up the root org id to run tests so you'll need to have AWS creds set up to accomodate that behavior.
+* You can run the provided tests against the real lambda function by getting the deployed function name from AWS and setting the `RUN_LOCALLY` env variable
+
+```
+RUN_LOCALLY='false' LAMBDA_FUNCTION_NAME='<name from AWS>' pytest ./handler_tests/<handler>/test.py -rA --capture=sys
+```
 '''
 import abc
 import builtins
@@ -33,6 +40,7 @@ import typing_extensions
 
 from ._jsii import *
 
+import aws_cdk
 import aws_cdk.aws_iam
 import aws_cdk.custom_resources
 import constructs
@@ -76,6 +84,11 @@ class OrganizationOU(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resource")
+    def resource(self) -> aws_cdk.CustomResource:
+        return typing.cast(aws_cdk.CustomResource, jsii.get(self, "resource"))
+
 
 @jsii.data_type(
     jsii_type="@renovosolutions/cdk-library-aws-organization.OrganizationOUProps",
